@@ -33,9 +33,8 @@ from typing import Iterable, Mapping, MutableMapping
 import requests
 from urllib3 import Retry
 
-from internetarchive import auth, catalog
+from internetarchive import auth, catalog, files, item, search, session
 from internetarchive import config as config_module
-from internetarchive import files, item, search, session
 from internetarchive.exceptions import AuthenticationError
 
 
@@ -313,6 +312,7 @@ def download(
     on_the_fly: bool = False,
     return_responses: bool = False,
     no_change_timestamp: bool = False,
+    timeout: int | float | tuple[int, float] | None = None,
     **get_item_kwargs,
 ) -> list[requests.Request | requests.Response]:
     r"""Download files from an item.
@@ -375,6 +375,7 @@ def download(
         on_the_fly=on_the_fly,
         return_responses=return_responses,
         no_change_timestamp=no_change_timestamp,
+        timeout=timeout,
     )
     return r
 
@@ -578,7 +579,7 @@ def get_user_info(access_key: str, secret_key: str) -> dict[str, str]:
     """
     u = "https://s3.us.archive.org"
     p = {"check_auth": 1}
-    r = requests.get(u, params=p, auth=auth.S3Auth(access_key, secret_key))
+    r = requests.get(u, params=p, auth=auth.S3Auth(access_key, secret_key), timeout=10)
     r.raise_for_status()
     j = r.json()
     if j.get("error"):
