@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -28,7 +27,9 @@ usage:
 options:
     -h, --help
     -v, --version
-    -c, --config-file FILE  Use FILE as config file.
+    -c, --config-file FILE  Use FILE as config file. (Can also be set with the
+                            IA_CONFIG_FILE environment variable. The option takes
+                            precedence when both are used.)
     -l, --log               Turn on logging [default: False].
     -d, --debug             Turn on verbose logging [default: False].
     -i, --insecure          Use HTTP for all requests instead of HTTPS [default: false]
@@ -55,76 +56,76 @@ Documentation for 'ia' is available at:
 
 See 'ia help <command>' for help on a specific command.
 """
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import annotations
 
-import sys
-import os
 import difflib
 import errno
-from pkg_resources import iter_entry_points, DistributionNotFound
+import os
+import sys
 
 from docopt import docopt, printable_usage
-from schema import Schema, Or, SchemaError
-import six
+from pkg_resources import DistributionNotFound, iter_entry_points
+from schema import Or, Schema, SchemaError  # type: ignore[import]
 
 from internetarchive import __version__
 from internetarchive.api import get_session
 from internetarchive.utils import suppress_keyboard_interrupt_message
+
 suppress_keyboard_interrupt_message()
 
 
-cmd_aliases = dict(
-    co='configure',
-    md='metadata',
-    up='upload',
-    do='download',
-    rm='delete',
-    se='search',
-    ta='tasks',
-    ls='list',
-    cp='copy',
-    mv='move',
-    re='reviews',
-)
+cmd_aliases = {
+    'co': 'configure',
+    'md': 'metadata',
+    'up': 'upload',
+    'do': 'download',
+    'rm': 'delete',
+    'se': 'search',
+    'ta': 'tasks',
+    'ls': 'list',
+    'cp': 'copy',
+    'mv': 'move',
+    're': 'reviews',
+}
 
 
-def load_ia_module(cmd):
+def load_ia_module(cmd: str):
     """Dynamically import ia module."""
     try:
         if cmd in list(cmd_aliases.keys()) + list(cmd_aliases.values()):
-            _module = 'internetarchive.cli.ia_{0}'.format(cmd)
+            _module = f'internetarchive.cli.ia_{cmd}'
             return __import__(_module, fromlist=['internetarchive.cli'])
         else:
-            _module = 'ia_{0}'.format(cmd)
+            _module = f'ia_{cmd}'
             for ep in iter_entry_points('internetarchive.cli.plugins'):
                 if ep.name == _module:
                     return ep.load()
             raise ImportError
     except (ImportError, DistributionNotFound):
-        print("error: '{0}' is not an ia command! See 'ia help'".format(cmd),
+        print(f"error: '{cmd}' is not an ia command! See 'ia help'",
               file=sys.stderr)
         matches = '\t'.join(difflib.get_close_matches(cmd, cmd_aliases.values()))
         if matches:
-            print('\nDid you mean one of these?\n\t{0}'.format(matches))
+            print(f'\nDid you mean one of these?\n\t{matches}', file=sys.stderr)
         sys.exit(127)
 
 
-def main():
+def main() -> None:
     """This is the CLI driver for ia-wrapper."""
     args = docopt(__doc__, version=__version__, options_first=True)
 
     # Validate args.
     s = Schema({
-        six.text_type: bool,
-        '--config-file': Or(None, *six.string_types),
-        '--host': Or(None, *six.string_types),
+        str: bool,
+        '--config-file': Or(None, str),
+        '--host': Or(None, str),
         '<args>': list,
         '<command>': Or(str, lambda _: 'help'),
     })
     try:
         args = s.validate(args)
     except SchemaError as exc:
-        print('{0}\n{1}'.format(str(exc), printable_usage(__doc__)), file=sys.stderr)
+        print(f'{exc}\n{printable_usage(__doc__)}', file=sys.stderr)
         sys.exit(1)
 
     # Get subcommand.
@@ -141,25 +142,25 @@ def main():
 
     if cmd != 'configure' and args['--config-file']:
         if not os.path.isfile(args['--config-file']):
-            print('--config-file should be a readable file.\n{0}'.format(
-                printable_usage(__doc__)), file=sys.stderr)
+            print(f'--config-file should be a readable file.\n{printable_usage(__doc__)}',
+                  file=sys.stderr)
             sys.exit(1)
 
     argv = [cmd] + args['<args>']
 
-    config = dict()
+    config: dict[str, dict] = {}
     if args['--log']:
         config['logging'] = {'level': 'INFO'}
     elif args['--debug']:
         config['logging'] = {'level': 'DEBUG'}
 
     if args['--insecure']:
-        config['general'] = dict(secure=False)
+        config['general'] = {'secure': False}
     if args['--host']:
         if config.get('general'):
             config['general']['host'] = args['--host']
         else:
-            config['general'] = dict(host=args['--host'])
+            config['general'] = {'host': args['--host']}
 
     session = get_session(config_file=args['--config-file'],
                           config=config,
@@ -168,7 +169,7 @@ def main():
     ia_module = load_ia_module(cmd)
     try:
         sys.exit(ia_module.main(argv, session))
-    except IOError as e:
+    except OSError as e:
         # Handle Broken Pipe errors.
         if e.errno == errno.EPIPE:
             sys.stderr.close()
