@@ -20,7 +20,6 @@
 
 usage:
     ia download <identifier> [<file>]... [options]...
-    ia download <identifier> <file> --stdout [options]...
     ia download --itemlist=<file> [options]...
     ia download --search=<query> [options]...
     ia download --help
@@ -61,9 +60,16 @@ options:
                                              the source material.
     -p, --parameters=<key:value>...          Parameters to send with your query (e.g. `cnt=0`).
     -a, --download-history                   Also download files from the history directory.
+    --source=<val>...                        Filter files based on their source value in files.xml
+                                             (i.e. `original`, `derivative`, `metadata`).
+    --exclude-source=<val>...                Filter files based on their source value in files.xml
+                                             (i.e. `original`, `derivative`, `metadata`).
+    -t, --timeout=<val>                      Set a timeout for download requests.
+                                             This sets both connect and read timeout.
 """
 from __future__ import annotations
 
+import ast
 import os
 import sys
 from os.path import exists as dir_exists
@@ -84,6 +90,7 @@ def main(argv, session: ArchiveSession) -> None:
     # Validation error messages.
     destdir_msg = '--destdir must be a valid path to a directory.'
     itemlist_msg = '--itemlist must be a valid path to an existing file.'
+    timeout_msg = '--timeout must be an int or float.'
 
     # Validate args.
     s = Schema({
@@ -102,6 +109,10 @@ def main(argv, session: ArchiveSession) -> None:
         '--no-change-timestamp': Use(bool),
         '--download-history': Use(bool),
         '--parameters': Use(lambda x: get_args_dict(x, query_string=True)),
+        '--source': list,
+        '--exclude-source': list,
+        '--timeout': Or([], And(Use(lambda t: ast.literal_eval(t[0])), Or(int, float),
+                         error=timeout_msg))
     })
 
     try:
@@ -156,19 +167,6 @@ def main(argv, session: ArchiveSession) -> None:
 
     errors = []
     for i, identifier in enumerate(ids):
-        if args['--stdout']:
-            item = session.get_item(identifier)
-            f = list(item.get_files(args['<file>']))
-            try:
-                assert len(f) == 1
-            except AssertionError:
-                print(f'error: {identifier}/{args["<file>"][0]} does not exist!', file=sys.stderr)
-                sys.exit(1)
-            stdout_buf = sys.stdout.buffer
-            f[0].download(retries=args['--retries'],
-                          fileobj=stdout_buf,
-                          params=args['--parameters'])
-            sys.exit(0)
         try:
             identifier = identifier.strip()
         except AttributeError:
@@ -209,6 +207,10 @@ def main(argv, session: ArchiveSession) -> None:
             no_change_timestamp=args['--no-change-timestamp'],
             params=args['--parameters'],
             ignore_history_dir=ignore_history_dir,
+            source=args['--source'],
+            exclude_source=args['--exclude-source'],
+            stdout=args['--stdout'],
+            timeout=args['--timeout'],
         )
         if _errors:
             errors.append(_errors)
