@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -27,20 +26,17 @@ search engine.
 :copyright: (C) 2012-2019 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
-from __future__ import absolute_import, unicode_literals
-
 import itertools
 from logging import getLogger
 
-import six
+from requests.exceptions import ReadTimeout
 
 from internetarchive.auth import S3Auth
 
-
 log = getLogger(__name__)
 
 
-class Search(object):
+class Search:
     """This class represents an archive.org item search. You can use
     this class to search for Archive.org items using the advanced search
     engine.
@@ -60,23 +56,27 @@ class Search(object):
                  sorts=None,
                  params=None,
                  full_text_search=None,
+                 dsl_fts=None,
                  request_kwargs=None,
                  max_retries=None):
         params = params or {}
 
         self.session = archive_session
+        self.dsl_fts = False if not dsl_fts else True
+        if self.dsl_fts or full_text_search:
+            self.fts = True
+        else:
+            self.fts = False
         self.query = query
-        self.fields = fields or list()
-        self.sorts = sorts or list()
-        self.request_kwargs = request_kwargs or dict()
+        if self.fts and not self.dsl_fts:
+            self.query = f'!L {self.query}'
+        self.fields = fields or []
+        self.sorts = sorts or []
+        self.request_kwargs = request_kwargs or {}
         self._num_found = None
-        self.fts = False if not full_text_search else True
-        self.fts_url = '{0}//be-api.us.archive.org/ia-pub-fts-api'.format(
-            self.session.protocol)
-        self.scrape_url = '{0}//{1}/services/search/v1/scrape'.format(
-            self.session.protocol, self.session.host)
-        self.search_url = '{0}//{1}/advancedsearch.php'.format(
-            self.session.protocol, self.session.host)
+        self.fts_url = f'{self.session.protocol}//be-api.us.archive.org/ia-pub-fts-api'
+        self.scrape_url = f'{self.session.protocol}//{self.session.host}/services/search/v1/scrape'
+        self.search_url = f'{self.session.protocol}//{self.session.host}/advancedsearch.php'
         if self.session.access_key and self.session.secret_key:
             self.auth = S3Auth(self.session.access_key, self.session.secret_key)
         else:
@@ -84,9 +84,12 @@ class Search(object):
         self.max_retries = max_retries if max_retries is not None else 5
 
         # Initialize params.
-        default_params = dict(q=query)
+        default_params = {'q': self.query}
         if 'page' not in params:
-            default_params['count'] = 10000
+            if 'rows' in params:
+                params['page'] = 1
+            else:
+                default_params['count'] = 10000
         else:
             default_params['output'] = 'json'
         # In the beta endpoint 'scope' was called 'index'.
@@ -105,7 +108,7 @@ class Search(object):
         self.session.mount_http_adapter(max_retries=self.max_retries)
 
     def __repr__(self):
-        return 'Search(query={query!r})'.format(query=self.query)
+        return f'Search(query={self.query!r})'
 
     def __iter__(self):
         return self.iter_as_results()
@@ -115,47 +118,85 @@ class Search(object):
         if 'identifier' not in self.fields:
             self.fields.append('identifier')
         for k, v in enumerate(self.fields):
-            key = 'fl[{0}]'.format(k)
-            self.params[key] = v
+            self.params[f'fl[{k}]'] = v
 
         for i, field in enumerate(self.sorts):
-            self.params['sort[{0}]'.format(i)] = field
+            self.params[f'sort[{i}]'] = field
 
         self.params['output'] = 'json'
 
-        r = self.session.get(self.search_url, params=self.params, **self.request_kwargs)
+        r = self.session.get(self.search_url,
+                             params=self.params,
+                             auth=self.auth,
+                             **self.request_kwargs)
         j = r.json()
-        for item in j.get('response', {}).get('docs', []):
-            yield item
+        num_found = int(j['response']['numFound'])
+        if not self._num_found:
+            self._num_found = num_found
+        if j.get('error'):
+            yield j
+        yield from j.get('response', {}).get('docs', [])
 
     def _scrape(self):
         if self.fields:
             self.params['fields'] = ','.join(self.fields)
         if self.sorts:
             self.params['sorts'] = ','.join(self.sorts)
+        i = 0
+        num_found = None
         while True:
             r = self.session.post(self.scrape_url,
                                   params=self.params,
                                   auth=self.auth,
                                   **self.request_kwargs)
             j = r.json()
+            if j.get('error'):
+                yield j
+            if not num_found:
+                num_found = int(j['total'])
+            if not self._num_found:
+                self._num_found = num_found
             self._handle_scrape_error(j)
 
             self.params['cursor'] = j.get('cursor')
             for item in j['items']:
+                i += 1
                 yield item
             if 'cursor' not in j:
+                if i != num_found:
+                    raise ReadTimeout('The server failed to return results in the'
+                                      f' allotted amount of time for {r.request.url}')
                 break
 
     def _full_text_search(self):
-        r = self.session.get(self.fts_url,
-                             params=self.params,
-                             auth=self.auth,
-                             **self.request_kwargs)
-        j = r.json()
-        hits = j.get('hits', dict()).get('hits', list())
-        for h in hits:
-            yield h
+        d = {
+            'q': self.query,
+            'size': '10000',
+            'from': '0',
+            'scroll': 'true',
+        }
+
+        if 'scope' in self.params:
+            d['scope'] = self.params['scope']
+
+        if 'size' in self.params:
+            d['scroll'] = False
+            d['size'] = self.params['size']
+
+        while True:
+            r = self.session.post(self.fts_url,
+                                  json=d,
+                                  auth=self.auth,
+                                  **self.request_kwargs)
+            j = r.json()
+            scroll_id = j.get('_scroll_id')
+            hits = j.get('hits', {}).get('hits')
+            if not hits:
+                return
+            yield from hits
+            if not hits or d['scroll'] is False:
+                break
+            d['scroll_id'] = scroll_id
 
     def _make_results_generator(self):
         if self.fts:
@@ -175,21 +216,32 @@ class Search(object):
         self.params['output'] = 'json'
         r = self.session.get(self.search_url, params=self.params, **self.request_kwargs)
         j = r.json()
-        for agg in j.get('response', dict()).get('aggregations', dict()).items():
+        if j.get('error'):
+            yield j
+        for agg in j.get('response', {}).get('aggregations', {}).items():
             yield {agg[0]: agg[1]}
 
     @property
     def num_found(self):
         if not self._num_found:
-            p = self.params.copy()
-            p['total_only'] = 'true'
-            r = self.session.post(self.scrape_url,
-                                  params=p,
-                                  auth=self.auth,
-                                  **self.request_kwargs)
-            j = r.json()
-            self._handle_scrape_error(j)
-            self._num_found = j.get('total')
+            if not self.fts:
+                p = self.params.copy()
+                p['total_only'] = 'true'
+                r = self.session.post(self.scrape_url,
+                                      params=p,
+                                      auth=self.auth,
+                                      **self.request_kwargs)
+                j = r.json()
+                self._handle_scrape_error(j)
+                self._num_found = j.get('total')
+            else:
+                self.params['q'] = self.query
+                r = self.session.get(self.fts_url,
+                                     params=self.params,
+                                     auth=self.auth,
+                                     **self.request_kwargs)
+                j = r.json()
+                self._num_found = j.get('hits', {}).get('total')
         return self._num_found
 
     def _handle_scrape_error(self, j):
@@ -197,8 +249,7 @@ class Search(object):
             if all(s in j['error'].lower() for s in ['invalid', 'secret']):
                 if not j['error'].endswith('.'):
                     j['error'] += '.'
-                raise ValueError("{0} Try running 'ia configure' "
-                                 "and retrying.".format(j['error']))
+                raise ValueError(f"{j['error']} Try running 'ia configure' and retrying.")
             raise ValueError(j.get('error'))
 
     def _get_item_from_search_result(self, search_result):
@@ -208,18 +259,14 @@ class Search(object):
         return SearchIterator(self, self._make_results_generator())
 
     def iter_as_items(self):
-        if six.PY2:
-            _map = itertools.imap(self._get_item_from_search_result,
-                                  self._make_results_generator())
-        else:
-            _map = map(self._get_item_from_search_result, self._make_results_generator())
+        _map = map(self._get_item_from_search_result, self._make_results_generator())
         return SearchIterator(self, _map)
 
     def __len__(self):
         return self.num_found
 
 
-class SearchIterator(object):
+class SearchIterator:
     """This class is an iterator wrapper for search results.
 
     It provides access to the underlying Search, and supports
@@ -233,13 +280,10 @@ class SearchIterator(object):
         return self.search.num_found
 
     def __next__(self):
-        return self.iterator.__next__()
-
-    def next(self):
-        return self.iterator.next()
+        return next(self.iterator)
 
     def __iter__(self):
         return self
 
     def __repr__(self):
-        return '{0.__class__.__name__}({0.search!r}, {0.iterator!r})'.format(self)
+        return f'{self.__class__.__name__}({self.search!r}, {self.iterator!r})'
