@@ -1,3 +1,4 @@
+import logging
 import os
 import re
 import types
@@ -214,14 +215,15 @@ def test_download_checksum(tmpdir, caplog):
         assert load_file('nasa/nasa_meta.xml') == 'overwrite based on md5'
 
         # test no overwrite based on checksum.
-        rsps.reset()
-        rsps.add(responses.GET, DOWNLOAD_URL_RE,
-                 body=load_test_data_file('nasa_meta.xml'))
-        nasa_item.download(files='nasa_meta.xml', checksum=True)
-        nasa_item.download(files='nasa_meta.xml', checksum=True)
+        with caplog.at_level(logging.DEBUG):
+            rsps.reset()
+            rsps.add(responses.GET, DOWNLOAD_URL_RE,
+                     body=load_test_data_file('nasa_meta.xml'))
+            nasa_item.download(files='nasa_meta.xml', checksum=True, verbose=True)
+            nasa_item.download(files='nasa_meta.xml', checksum=True, verbose=True)
 
-        assert 'skipping nasa' in caplog.text
-        assert 'nasa_meta.xml, file already exists based on checksum.' in caplog.text
+            assert 'skipping nasa' in caplog.text
+            assert 'nasa_meta.xml, file already exists based on checksum.' in caplog.text
 
 
 def test_download_destdir(tmpdir, nasa_item):
@@ -278,10 +280,9 @@ def test_download_verbose(tmpdir, capsys, nasa_item):
     with IaRequestsMock(assert_all_requests_are_fired=False) as rsps:
         rsps.add(responses.GET, DOWNLOAD_URL_RE,
                  body='no dest dir',
-                 adding_headers={'content-length': '100'})
+                 adding_headers={'content-length': '11'})
         nasa_item.download(files='nasa_meta.xml', verbose=True)
         out, err = capsys.readouterr()
-        print(repr(err))
         assert 'downloading nasa_meta.xml' in err
 
 
@@ -406,7 +407,10 @@ def test_upload_503(capsys, nasa_item):
     with IaRequestsMock(assert_all_requests_are_fired=False) as rsps:
         _expected_headers = deepcopy(EXPECTED_S3_HEADERS)
         rsps.add(responses.GET, S3_URL_RE,
-                 body='{"over_limit": "1"}')
+                 body='{"over_limit": "1"}',
+                 adding_headers={'content-length': '19'}
+                 )
+        _expected_headers['content-length'] = '296'
         rsps.add(responses.PUT, S3_URL_RE,
                  body=body,
                  adding_headers=_expected_headers,
@@ -496,6 +500,7 @@ def test_upload_delete(tmpdir, nasa_item):
             '4133-a207-3141d4d74096</RequestId></Error>')
 
     _expected_headers = deepcopy(EXPECTED_S3_HEADERS)
+    _expected_headers['content-length'] = '383'
     del _expected_headers['x-archive-meta00-scanner']
     tmpdir.chdir()
     test_file = os.path.join(str(tmpdir), 'test.txt')
