@@ -1,15 +1,13 @@
-# -*- coding: utf-8 -*-
-import io
 import string
 
-from tests.conftest import IaRequestsMock, NASA_METADATA_PATH
-
-import six
 import internetarchive.utils
+from tests.conftest import NASA_METADATA_PATH, IaRequestsMock
 
 
 def test_utils():
-    list(internetarchive.utils.chunk_generator(io.open(__file__, encoding='utf-8'), 10))
+    with open(__file__, encoding='utf-8') as fh:
+        list(internetarchive.utils.chunk_generator(fh, 10))
+
     ifp = internetarchive.utils.IterableToFileAdapter([1, 2], 200)
     assert len(ifp) == 200
     ifp.read()
@@ -43,16 +41,7 @@ def test_validate_s3_identifier():
 def test_get_md5():
     with open(__file__, 'rb') as fp:
         md5 = internetarchive.utils.get_md5(fp)
-    assert isinstance(md5, six.string_types)
-
-
-def test_map2x():
-    keys = ('first', 'second')
-    columns = ('first', 'second')
-    for key, value in internetarchive.utils.map2x(None, keys, columns):
-        assert key == value
-    for key, value in internetarchive.utils.map2x(lambda k, v: [k, v], keys, columns):
-        assert key == value
+    assert isinstance(md5, str)
 
 
 def test_IdentifierListAsItems(session):
@@ -90,3 +79,19 @@ def test_get_file_size():
     with open(NASA_METADATA_PATH) as fp:
         s = internetarchive.utils.get_file_size(fp)
     assert s == 7557
+
+
+def test_is_valid_metadata_key():
+    # Keys starting with "xml" should also be invalid
+    # due to the XML specification, but are supported
+    # by the Internet Archive.
+    valid = ('adaptive_ocr', 'bookreader-defaults', 'frames_per_second',
+             'identifier', 'possible-copyright-status', 'index[0]')
+    invalid = ('Analog Format', "Date of transfer (probably today's date)",
+               '_metadata_key', '58', '_', '<invalid>', 'a')
+
+    for metadata_key in valid:
+        assert internetarchive.utils.is_valid_metadata_key(metadata_key)
+
+    for metadata_key in invalid:
+        assert not internetarchive.utils.is_valid_metadata_key(metadata_key)
